Changelog
=========

1.0.1 (2013-02-21)
------------------

-  Added hero unit
  [Veit Schiele]
- Switched to 9 span main column
  [Veit Schiele]

1.0 (2013-01-15)
----------------

- Initial implementation with the `Diazo <http://docs.diazo.org/>`_ rules and
  `LESS <http://lesscss.org/>`_ of the `Diazo Bootstrap Framework
  <https://github.com/veit/diazo_bootstrap.git>`_.
  [Veit Schiele]

